@@ -79,6 +79,7 @@ private slots:
     void MapSlot();
     void BookInfoSlot();
     void ShopSlot();
+    void ScrollToTopSlot();
 
 public slots:
     void Print(QString);
@@ -100,7 +101,7 @@ public slots:
     Item* AddMealPickItem(QString name);
     Weapon* AddWeaponPickItem(QString name, QString className);
     Item* AddHealingPickItem(QString name, int enduranceDelta);
-    void PickItems(int max);
+    int PickItems(int max);
     int SelectGoldCrowns(int min);
     int GetRandomNumber();
     int GetRandomNumberWithBonus(int bonus);
