@@ -273,6 +273,8 @@ Enemy* Book::ParseEnemy(Section* section, QXmlStreamReader* reader)
                 e->ExitScript = reader->readElementText();
             else if (name == "roundscript")
                 e->RoundScript = reader->readElementText();
+            else if (name == "damagescript")
+                e->DamageScript = reader->readElementText();
         }else if(token == QXmlStreamReader::EndElement && name == eName)
             break;
     }
@@ -287,6 +289,7 @@ Weapon* Book::ParseWeapon(Section* section, QXmlStreamReader* reader)
     QXmlStreamAttributes attrs = reader->attributes();
     w->Name = attrs.value("name").toString();
     w->Description = attrs.value("description").toString();
+    w->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     w->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
 
     QString tclass = attrs.value("class").toString();
@@ -315,8 +318,10 @@ Item* Book::ParseItem(Section* section, QXmlStreamReader* reader)
     QXmlStreamAttributes attrs = reader->attributes();
     i->Name = attrs.value("name").toString();
     i->Description = attrs.value("description").toString();
+    i->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     i->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
     i->SetIsMeal(attrs.value("ismeal").toString().toInt() == 1);
+    i->SetIsArrow(attrs.value("isarrow").toString().toInt() == 1);
     i->SetIsBackpack(attrs.value("isbackpack").toString().toInt() == 1);
     i->SetCombatskillDelta(attrs.value("combatskilldelta").toString().toInt());
     i->SetEnduranceDelta(attrs.value("endurancedelta").toString().toInt());
@@ -345,6 +350,7 @@ ShopItem* Book::ParseShopItem(Section* section, QXmlStreamReader* reader)
     QXmlStreamAttributes attrs = reader->attributes();
     i->Name = attrs.value("name").toString();
     i->Description = attrs.value("description").toString();
+    i->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     i->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
     i->SetIsMeal(attrs.value("ismeal").toString().toInt() == 1);
     i->SetIsBackpack(attrs.value("isbackpack").toString().toInt() == 1);
@@ -446,6 +452,8 @@ bool Book::Save(QString filename)
                 writer.writeTextElement("exitscript", e->ExitScript);
             if (!e->RoundScript.isEmpty())
                 writer.writeTextElement("roundscript", e->RoundScript);
+            if (!e->DamageScript.isEmpty())
+                writer.writeTextElement("damagescript", e->DamageScript);
 
             writer.writeEndElement();
         }
