@@ -506,32 +506,37 @@ void StatusWindow::TakeItemSlot()
         ShowData();
         return;
     }else{
-        //Take normal item:
-        if (!m_Player->HasBackpack() && i->GetIsBackpack()){
-            m_Player->SetHasBackpack(true);
-            m_Section->Items.removeOne(i);
-            ShowData();
-            return;
-        }else if (!m_Player->HasBackpack()){
-            QMessageBox msgBox(this);
-            msgBox.setText("You don't have the backpack and cannot carry any item.");
-            msgBox.exec();
-            return;
-        }else if (m_Player->HasBackpack() && i->GetIsBackpack()){
-            QMessageBox msgBox(this);
-            msgBox.setText("You have the backpack and cannot carry another one.");
-            msgBox.exec();
-            return;
-        }else if (m_Player->IsBackpackFull()){
-            QMessageBox msgBox(this);
-            msgBox.setText("You cannot carry more items.");
-            msgBox.exec();
-            return;
+        //Take arrows:
+        if (i->GetIsArrow()){
+            m_Player->Arrows += i->GetQuantity();
         }else{
-            m_Player->Items.append(i);
-            m_Section->Items.removeOne(i);
-            ShowData();
-            return;
+            //Take normal item:
+            if (!m_Player->HasBackpack() && i->GetIsBackpack()){
+                m_Player->SetHasBackpack(true);
+                m_Section->Items.removeOne(i);
+                ShowData();
+                return;
+            }else if (!m_Player->HasBackpack()){
+                QMessageBox msgBox(this);
+                msgBox.setText("You don't have the backpack and cannot carry any item.");
+                msgBox.exec();
+                return;
+            }else if (m_Player->HasBackpack() && i->GetIsBackpack()){
+                QMessageBox msgBox(this);
+                msgBox.setText("You have the backpack and cannot carry another one.");
+                msgBox.exec();
+                return;
+            }else if (m_Player->IsBackpackFull()){
+                QMessageBox msgBox(this);
+                msgBox.setText("You cannot carry more items.");
+                msgBox.exec();
+                return;
+            }else{
+                m_Player->Items.append(i);
+                m_Section->Items.removeOne(i);
+                ShowData();
+                return;
+            }
         }
     }
 }
